@@ -40,9 +40,10 @@ copyright = '2008, Georg Brandl'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.1'
+import sphinx
+version = sphinx.__version__
 # The full version, including alpha/beta/rc tags.
-release = '0.1'
+release = version
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -100,7 +101,7 @@ html_additional_pages = {'index': 'index.html'}
 # If true, the reST sources are included in the HTML build as _sources/<name>.
 #html_copy_source = True
 
-html_use_opensearch = True
+html_use_opensearch = 'http://sphinx.pocoo.org'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'Sphinxdoc'
@@ -118,10 +119,12 @@ htmlhelp_basename = 'Sphinxdoc'
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
 latex_documents = [('contents', 'sphinx.tex', 'Sphinx Documentation',
-                    'Georg Brandl', 'manual')]
+                    'Georg Brandl', 'manual', 1)]
 
 latex_logo = '_static/sphinx.png'
 
+#latex_use_parts = True
+
 # Additional stuff for the LaTeX preamble.
 #latex_preamble = ''
 
