@@ -25,7 +25,7 @@ from docutils.frontend import OptionParser
 from docutils.readers.doctree import Reader as DoctreeReader
 
 from sphinx import addnodes
-from sphinx.util import mtimes_of_files, ensuredir, relative_uri, SEP, os_path
+from sphinx.util import ensuredir, relative_uri, SEP, os_path
 from sphinx.htmlhelp import build_hhx
 from sphinx.htmlwriter import HTMLWriter, HTMLTranslator, SmartyPantsHTMLTranslator
 from sphinx.latexwriter import LaTeXWriter
@@ -50,6 +50,7 @@ class Builder(object):
 
     def __init__(self, app, env=None, freshenv=False):
         self.srcdir = app.srcdir
+        self.confdir = app.confdir
         self.outdir = app.outdir
         self.doctreedir = app.doctreedir
         if not path.isdir(self.doctreedir):
@@ -274,6 +275,8 @@ class StandaloneHTMLBuilder(Builder):
         """Load templates."""
         self.init_templates()
         self.init_translator_class()
+        if self.config.html_file_suffix:
+            self.out_suffix = self.config.html_file_suffix
 
     def init_translator_class(self):
         if self.config.html_translator_class:
@@ -323,6 +326,9 @@ class StandaloneHTMLBuilder(Builder):
         logo = self.config.html_logo and \
                path.basename(self.config.html_logo) or ''
 
+        if not isinstance(self.config.html_use_opensearch, basestring):
+            self.warn('html_use_opensearch config value must now be a string')
+
         self.globalcontext = dict(
             project = self.config.project,
             release = self.config.release,
@@ -464,15 +470,16 @@ class StandaloneHTMLBuilder(Builder):
             self.handle_page('modindex', modindexcontext, 'modindex.html')
 
         # the search page
-        self.info(' search', nonl=1)
-        self.handle_page('search', {}, 'search.html')
+        if self.name != 'htmlhelp':
+            self.info(' search', nonl=1)
+            self.handle_page('search', {}, 'search.html')
 
         # additional pages from conf.py
         for pagename, template in self.config.html_additional_pages.items():
             self.info(' '+pagename, nonl=1)
             self.handle_page(pagename, {}, template)
 
-        if self.config.html_use_opensearch:
+        if self.config.html_use_opensearch and self.name != 'htmlhelp':
             self.info(' opensearch', nonl=1)
             fn = path.join(self.outdir, '_static', 'opensearch.xml')
             self.handle_page('opensearch', {}, 'opensearch.xml', outfilename=fn)
@@ -487,19 +494,13 @@ class StandaloneHTMLBuilder(Builder):
                 self.info(' '+src, nonl=1)
                 shutil.copyfile(path.join(self.srcdir, src),
                                 path.join(self.outdir, '_images', dest))
-            # the logo is handled differently
-            if self.config.html_logo:
-                logobase = path.basename(self.config.html_logo)
-                self.info(' '+logobase, nonl=1)
-                shutil.copyfile(path.join(self.srcdir, self.config.html_logo),
-                                path.join(self.outdir, '_static', logobase))
             self.info()
 
         # copy static files
         self.info(bold('copying static files...'))
         ensuredir(path.join(self.outdir, '_static'))
         staticdirnames = [path.join(path.dirname(__file__), 'static')] + \
-                         [path.join(self.srcdir, spath)
+                         [path.join(self.confdir, spath)
                           for spath in self.config.html_static_path]
         for staticdirname in staticdirnames:
             for filename in os.listdir(staticdirname):
@@ -557,7 +558,7 @@ class StandaloneHTMLBuilder(Builder):
     # --------- these are overwritten by the Pickle builder
 
     def get_target_uri(self, docname, typ=None):
-        return docname + '.html'
+        return docname + self.out_suffix
 
     def handle_page(self, pagename, addctx, templatename='page.html',
                     outfilename=None):
@@ -578,7 +579,7 @@ class StandaloneHTMLBuilder(Builder):
 
         output = self.templates.render(templatename, ctx)
         if not outfilename:
-            outfilename = path.join(self.outdir, os_path(pagename) + '.html')
+            outfilename = path.join(self.outdir, os_path(pagename) + self.out_suffix)
         ensuredir(path.dirname(outfilename)) # normally different from self.outdir
         try:
             f = codecs.open(outfilename, 'w', 'utf-8')
@@ -626,11 +627,11 @@ class PickleHTMLBuilder(StandaloneHTMLBuilder):
     def handle_page(self, pagename, ctx, templatename='page.html',
                     outfilename=None):
         ctx['current_page_name'] = pagename
-        sidebarfile = self.config.html_sidebars.get(pagename, '')
+        sidebarfile = self.config.html_sidebars.get(pagename)
         if sidebarfile:
-            ctx['customsidebar'] = path.join(self.srcdir, sidebarfile)
+            ctx['customsidebar'] = sidebarfile
         if not outfilename:
-            outfilename = path.join(self.outdir, os_path(pagename) + '.fpickle')
+            outfilename = path.join(self.outdir, os_path(pagename) + self.out_suffix)
         ensuredir(path.dirname(outfilename))
         f = open(outfilename, 'wb')
         try:
@@ -687,6 +688,11 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
     # don't copy the reST source
     copysource = False
 
+    def init(self):
+        StandaloneHTMLBuilder.init(self)
+        # the output files for HTML help must be .html only
+        self.out_suffix = '.html'
+
     def handle_finish(self):
         build_hhx(self, self.outdir, self.config.htmlhelp_basename)
 
@@ -746,13 +752,17 @@ class LaTeXBuilder(Builder):
 
         self.init_document_data()
 
-        for docname, targetname, title, author, docclass in self.document_data:
+        for entry in self.document_data:
+            docname, targetname, title, author, docclass = entry[:5]
+            toctree_only = False
+            if len(entry) > 5:
+                toctree_only = entry[5]
             destination = FileOutput(
                 destination_path=path.join(self.outdir, targetname),
                 encoding='utf-8')
             self.info("processing " + targetname + "... ", nonl=1)
-            doctree = self.assemble_doctree(
-                docname, appendices=(docclass == 'manual') and appendices or [])
+            doctree = self.assemble_doctree(docname, toctree_only,
+                appendices=(docclass == 'manual') and appendices or [])
             self.info("writing... ", nonl=1)
             doctree.settings = docsettings
             doctree.settings.author = author
@@ -762,7 +772,7 @@ class LaTeXBuilder(Builder):
             docwriter.write(doctree, destination)
             self.info("done")
 
-    def assemble_doctree(self, indexfile, appendices):
+    def assemble_doctree(self, indexfile, toctree_only, appendices):
         self.docnames = set([indexfile] + appendices)
         self.info(darkgreen(indexfile) + " ", nonl=1)
         def process_tree(docname, tree):
@@ -776,14 +786,25 @@ class LaTeXBuilder(Builder):
                         subtree = process_tree(includefile,
                                                self.env.get_doctree(includefile))
                         self.docnames.add(includefile)
-                    except:
+                    except Exception:
                         self.warn('%s: toctree contains ref to nonexisting file %r' %
                                   (docname, includefile))
                     else:
+                        newnodes.append(addnodes.start_of_file())
                         newnodes.extend(subtree.children)
                 toctreenode.parent.replace(toctreenode, newnodes)
             return tree
-        largetree = process_tree(indexfile, self.env.get_doctree(indexfile))
+        tree = self.env.get_doctree(indexfile)
+        if toctree_only:
+            # extract toctree nodes from the tree and put them in a fresh document
+            new_tree = new_document('<latex output>')
+            new_sect = nodes.section()
+            new_sect += nodes.title('<temp>', '<temp>')
+            new_tree += new_sect
+            for node in tree.traverse(addnodes.toctree):
+                new_sect += node
+            tree = new_tree
+        largetree = process_tree(indexfile, tree)
         largetree.extend(appendices)
         self.info()
         self.info("resolving references...")
@@ -818,8 +839,7 @@ class LaTeXBuilder(Builder):
         # the logo is handled differently
         if self.config.latex_logo:
             logobase = path.basename(self.config.latex_logo)
-            self.info(' '+logobase, nonl=1)
-            shutil.copyfile(path.join(self.srcdir, self.config.latex_logo),
+            shutil.copyfile(path.join(self.confdir, self.config.latex_logo),
                             path.join(self.outdir, logobase))
 
         self.info(bold('copying TeX support files...'))
